#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 smallcheck
version:              1.2.1.1
visibility:           public
id:                   smallcheck-1.2.1.1-4lUlLiOcXtT4ZT5qzc3dGk
key:                  smallcheck-1.2.1.1-4lUlLiOcXtT4ZT5qzc3dGk
license:              BSD-3-Clause
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Colin Runciman, Roman Cheplyaka
homepage:             https://github.com/Bodigrim/smallcheck
synopsis:             A property-based testing library
description:
    As of 2023, this library is largely obsolete: arbitrary test generators
    with shrinking such as [falsify](https://hackage.haskell.org/package/falsify)
    offer much better user experience.

    SmallCheck is a testing library that allows to verify properties
    for all test cases up to some depth. The test cases are generated
    automatically by SmallCheck.

category:             Testing
abi:                  5b69847ea0884b1a5c5ad7096ed53bb7
exposed:              True
exposed-modules:
    Test.SmallCheck Test.SmallCheck.Drivers Test.SmallCheck.Series

hidden-modules:
    Test.SmallCheck.Property Test.SmallCheck.SeriesMonad
    Test.SmallCheck.Property.Result

import-dirs:          /usr/lib/ghc-9.6.6/site-local/smallcheck-1.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/smallcheck-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/smallcheck-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-smallcheck
hs-libraries:         HSsmallcheck-1.2.1.1-4lUlLiOcXtT4ZT5qzc3dGk
depends:
    base-4.18.2.1 logict-0.8.2.0-GEjm2Bw5g479zqYXloiNO1 mtl-2.3.1
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/haskell-smallcheck/html/smallcheck.haddock
haddock-html:         /usr/share/doc/haskell-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

